@@ -14,7 +14,7 @@ class ContextUpdater:
 
     def __init__(self, data: SkillRequestType,
                  dictionary: Type[Dictionary] = None,
-                 vault: BaseModel = None):
+                 vault = None):
         # Default parameters for find state and complete it
         self.data = data
         self.context = data.context
